about summary refs log tree commit diff
diff options
context:
space:
mode:
authorFlorian Klink <flokli@flokli.de>2022-10-28T14·26+0200
committerflokli <flokli@flokli.de>2022-11-08T17·57+0000
commit7ac36fd8db2a39a7e2528eec6debe29b675908a0 (patch)
tree20e920a783696633941a9470956b2a42b2b5a1dc
parent442384f6e52abd454733068c945e06a16b97a655 (diff)
chore(tvix/proto/castore.proto): rename link to symlinks r/5271
Make it clear these are symlinks, not hardlinks.

The term "link" is too heavily correlated to other meanings in IPFS/IPLD
world, and calling this symlink removes this confusion.

Change-Id: Id3f1eaa32098510b05f3e1a1348344503bcb4d5a
Reviewed-on: https://cl.tvl.fyi/c/depot/+/7129
Tested-by: BuildkiteCI
Reviewed-by: tazjin <tazjin@tvl.su>
Reviewed-by: Adam Joseph <adam@westernsemico.com>
-rw-r--r--tvix/proto/castore.proto10
1 files changed, 5 insertions, 5 deletions
diff --git a/tvix/proto/castore.proto b/tvix/proto/castore.proto
index b479595820..ec02660352 100644
--- a/tvix/proto/castore.proto
+++ b/tvix/proto/castore.proto
@@ -5,7 +5,7 @@ syntax = "proto3";
 
 package fossil.store;
 
 // A Directory can contain Directory, File or Link nodes.
 // Each of these nodes have a name attribute, which is the basename in that directory
 // and node type specific attributes.
 // The name attribute:
@@ -16,7 +16,7 @@ package fossil.store;
 message Directory {
     repeated DirectoryNode directories = 1;
     repeated FileNode files = 2;
-    repeated LinkNode links = 3;
+    repeated SymlinkNode symlinks = 3;
 }
 
 // A DirectoryNode represents a directory in a Directory.
@@ -26,7 +26,7 @@ message DirectoryNode {
     // The blake3 hash of a Directory message, serialized in protobuf canonical form.
     bytes ref = 2;
     // Number of child elements in the Directory referred to by ref.
     // Calculated by summing up the numbers of `directories`, `files` and `links`,
     // and for each directory, its size field. Used for inode number calculation
     // TODO(flokli): These numbers can't really be verified until you know the whole graph.
     //               Is this a problem? Should we instead only have this field
@@ -46,8 +46,8 @@ message FileNode {
     bool executable = 4;
 }
 
-// A LinkNode represents a symbolic link in a Directory.
-message LinkNode {
+// A SymlinkNode represents a symbolic link in a Directory.
+message SymlinkNode {
     // The (base)name of the symlink
     string name = 1;
     // The target of the symlink.
@@ -5,7 +5,7 @@ syntax = "proto3";
 package fossil.store;
 
-// A Directory can contain Directory, File or Link nodes.
+// A Directory can contain Directory, File or Symlink nodes.
 // Each of these nodes have a name attribute, which is the basename in that directory
 // and node type specific attributes.
@@ -26,7 +26,7 @@ message DirectoryNode {
     bytes ref = 2;
     // Number of child elements in the Directory referred to by ref.
-    // Calculated by summing up the numbers of `directories`, `files` and `links`,
+    // Calculated by summing up the numbers of `directories`, `files` and `symlinks`,
     // and for each directory, its size field. Used for inode number calculation
     // TODO(flokli): These numbers can't really be verified until you know the whole graph.